@@ -14,7 +14,22 @@ from email.mime.text import MIMEText
 from email.utils import formataddr
 
 
-def send_html_mail(subject, content, host, port, password, sender, sender_show_name, receiver):
+def send_html_mail(subject, content, host, port, password, sender, receiver):
+    """
+    发送HTML邮件
+    :param subject: 主体
+    :param content: HTML内容
+    :param host: 邮箱主机
+    :param port: 邮箱端口
+    :param password: 发信人密码
+    :param sender: 发信人邮箱
+    :param sender_show_name: 发信人显示名称
+    :param receiver: 接收者，可以是list
+    """
+    send_html_mail_with_nickname(subject, content, host, port, password, sender, '', receiver)
+
+
+def send_html_mail_with_nickname(subject, content, host, port, password, sender, sender_show_name, receiver):
     """
     发送HTML邮件
     :param subject: 主体
@@ -28,7 +43,10 @@ def send_html_mail(subject, content, host, port, password, sender, sender_show_n
     """
     msg = MIMEText(content, _subtype='html', _charset='utf-8')
     msg['Subject'] = subject
-    msg['From'] = formataddr([sender_show_name, sender])
+    if len(sender_show_name) > 0:
+        msg['From'] = formataddr([sender_show_name, sender])
+    else:
+        msg['From'] = sender
     s = smtplib.SMTP_SSL(host, port)
     s.login(sender, password)
     receiver_emails = []
